@@ -13,7 +13,7 @@ SPISSD1306 = ssd1306_spi.class_('SPISSD1306', ssd1306_base.SSD1306, spi.SPIDevic
 CONFIG_SCHEMA = cv.All(ssd1306_base.SSD1306_SCHEMA.extend({
     cv.GenerateID(): cv.declare_id(SPISSD1306),
     cv.Required(CONF_DC_PIN): pins.gpio_output_pin_schema,
-}).extend(cv.COMPONENT_SCHEMA).extend(spi.SPI_DEVICE_SCHEMA),
+}).extend(cv.COMPONENT_SCHEMA).extend(spi.spi_device_schema()),
                        cv.has_at_most_one_key(CONF_PAGES, CONF_LAMBDA))
 
 
