@@ -28,7 +28,7 @@ def validate_acceleration(value):
     try:
         value = float(value)
     except ValueError:
-        raise cv.Invalid("Expected acceleration as floating point number, got {}".format(value))
+        raise cv.Invalid(f"Expected acceleration as floating point number, got {value}")
 
     if value <= 0:
         raise cv.Invalid("Acceleration must be larger than 0 steps/s^2!")
@@ -48,7 +48,7 @@ def validate_speed(value):
     try:
         value = float(value)
     except ValueError:
-        raise cv.Invalid("Expected speed as floating point number, got {}".format(value))
+        raise cv.Invalid(f"Expected speed as floating point number, got {value}")
 
     if value <= 0:
         raise cv.Invalid("Speed must be larger than 0 steps/s!")
