@@ -1,34 +1,54 @@
-# coding=utf-8
 """Constants used by esphome."""
 
 MAJOR_VERSION = 1
-MINOR_VERSION = 14
-PATCH_VERSION = '5'
-__short_version__ = '{}.{}'.format(MAJOR_VERSION, MINOR_VERSION)
-__version__ = '{}.{}'.format(__short_version__, PATCH_VERSION)
+MINOR_VERSION = 15
+PATCH_VERSION = '0'
+__short_version__ = f'{MAJOR_VERSION}.{MINOR_VERSION}'
+__version__ = f'{__short_version__}.{PATCH_VERSION}'
 
 ESP_PLATFORM_ESP32 = 'ESP32'
 ESP_PLATFORM_ESP8266 = 'ESP8266'
 ESP_PLATFORMS = [ESP_PLATFORM_ESP32, ESP_PLATFORM_ESP8266]
 
-ALLOWED_NAME_CHARS = u'abcdefghijklmnopqrstuvwxyz0123456789_'
-ARDUINO_VERSION_ESP32_DEV = 'https://github.com/platformio/platform-espressif32.git#feature/stage'
-ARDUINO_VERSION_ESP32_1_0_0 = 'espressif32@1.5.0'
-ARDUINO_VERSION_ESP32_1_0_1 = 'espressif32@1.6.0'
-ARDUINO_VERSION_ESP32_1_0_2 = 'espressif32@1.9.0'
-ARDUINO_VERSION_ESP32_1_0_3 = 'espressif32@1.10.0'
-ARDUINO_VERSION_ESP32_1_0_4 = 'espressif32@1.11.0'
-ARDUINO_VERSION_ESP8266_DEV = 'https://github.com/platformio/platform-espressif8266.git#feature' \
-                              '/stage'
-ARDUINO_VERSION_ESP8266_2_5_0 = 'espressif8266@2.0.0'
-ARDUINO_VERSION_ESP8266_2_5_1 = 'espressif8266@2.1.0'
-ARDUINO_VERSION_ESP8266_2_5_2 = 'espressif8266@2.2.3'
-ARDUINO_VERSION_ESP8266_2_3_0 = 'espressif8266@1.5.0'
+ALLOWED_NAME_CHARS = 'abcdefghijklmnopqrstuvwxyz0123456789_'
+# Lookup table from ESP32 arduino framework version to latest platformio
+# package with that version
+# See also https://github.com/platformio/platform-espressif32/releases
+ARDUINO_VERSION_ESP32 = {
+    'dev': 'https://github.com/platformio/platform-espressif32.git',
+    '1.0.4': 'espressif32@1.12.4',
+    '1.0.3': 'espressif32@1.10.0',
+    '1.0.2': 'espressif32@1.9.0',
+    '1.0.1': 'espressif32@1.7.0',
+    '1.0.0': 'espressif32@1.5.0',
+}
+# See also https://github.com/platformio/platform-espressif8266/releases
+ARDUINO_VERSION_ESP8266 = {
+    'dev': 'https://github.com/platformio/platform-espressif8266.git',
+    '2.7.4': 'espressif8266@2.6.2',
+    '2.7.3': 'espressif8266@2.6.1',
+    '2.7.2': 'espressif8266@2.6.0',
+    '2.7.1': 'espressif8266@2.5.3',
+    '2.7.0': 'espressif8266@2.5.0',
+    '2.6.3': 'espressif8266@2.4.0',
+    '2.6.2': 'espressif8266@2.3.1',
+    '2.6.1': 'espressif8266@2.3.0',
+    '2.5.2': 'espressif8266@2.2.3',
+    '2.5.1': 'espressif8266@2.1.1',
+    '2.5.0': 'espressif8266@2.0.4',
+    '2.4.2': 'espressif8266@1.8.0',
+    '2.4.1': 'espressif8266@1.7.3',
+    '2.4.0': 'espressif8266@1.6.0',
+    '2.3.0': 'espressif8266@1.5.0',
+}
 SOURCE_FILE_EXTENSIONS = {'.cpp', '.hpp', '.h', '.c', '.tcc', '.ino'}
 HEADER_FILE_EXTENSIONS = {'.h', '.hpp', '.tcc'}
 
 CONF_ABOVE = 'above'
 CONF_ACCELERATION = 'acceleration'
+CONF_ACCELERATION_X = 'acceleration_x'
+CONF_ACCELERATION_Y = 'acceleration_y'
+CONF_ACCELERATION_Z = 'acceleration_z'
 CONF_ACCURACY = 'accuracy'
 CONF_ACCURACY_DECIMALS = 'accuracy_decimals'
 CONF_ACTION_ID = 'action_id'
@@ -42,16 +62,20 @@ CONF_ASSUMED_STATE = 'assumed_state'
 CONF_AT = 'at'
 CONF_ATTENUATION = 'attenuation'
 CONF_AUTH = 'auth'
+CONF_AUTO_MODE = 'auto_mode'
 CONF_AUTOMATION_ID = 'automation_id'
 CONF_AVAILABILITY = 'availability'
 CONF_AWAY = 'away'
 CONF_AWAY_CONFIG = 'away_config'
+CONF_BACKLIGHT_PIN = 'backlight_pin'
 CONF_BATTERY_LEVEL = 'battery_level'
+CONF_BATTERY_VOLTAGE = 'battery_voltage'
 CONF_BAUD_RATE = 'baud_rate'
 CONF_BELOW = 'below'
 CONF_BINARY = 'binary'
 CONF_BINARY_SENSOR = 'binary_sensor'
 CONF_BINARY_SENSORS = 'binary_sensors'
+CONF_BINDKEY = 'bindkey'
 CONF_BIRTH_MESSAGE = 'birth_message'
 CONF_BIT_DEPTH = 'bit_depth'
 CONF_BLUE = 'blue'
@@ -70,6 +94,8 @@ CONF_CALIBRATION = 'calibration'
 CONF_CAPACITANCE = 'capacitance'
 CONF_CARRIER_DUTY_PERCENT = 'carrier_duty_percent'
 CONF_CARRIER_FREQUENCY = 'carrier_frequency'
+CONF_CERTIFICATE = "certificate"
+CONF_CERTIFICATE_AUTHORITY = "certificate_authority"
 CONF_CHANGE_MODE_EVERY = 'change_mode_every'
 CONF_CHANNEL = 'channel'
 CONF_CHANNELS = 'channels'
@@ -97,9 +123,11 @@ CONF_CONDITION = 'condition'
 CONF_CONDITION_ID = 'condition_id'
 CONF_CONDUCTIVITY = 'conductivity'
 CONF_COOL_ACTION = 'cool_action'
+CONF_COOL_MODE = 'cool_mode'
 CONF_COUNT_MODE = 'count_mode'
 CONF_CRON = 'cron'
 CONF_CS_PIN = 'cs_pin'
+CONF_CSS_INCLUDE = 'css_include'
 CONF_CSS_URL = 'css_url'
 CONF_CURRENT = 'current'
 CONF_CURRENT_OPERATION = 'current_operation'
@@ -122,8 +150,10 @@ CONF_DELTA = 'delta'
 CONF_DEVICE = 'device'
 CONF_DEVICE_CLASS = 'device_class'
 CONF_DIMENSIONS = 'dimensions'
+CONF_DIO_PIN = 'dio_pin'
 CONF_DIR_PIN = 'dir_pin'
 CONF_DIRECTION = 'direction'
+CONF_DIRECTION_OUTPUT = 'direction_output'
 CONF_DISCOVERY = 'discovery'
 CONF_DISCOVERY_PREFIX = 'discovery_prefix'
 CONF_DISCOVERY_RETAIN = 'discovery_retain'
@@ -132,14 +162,18 @@ CONF_DIV_RATIO = 'div_ratio'
 CONF_DNS1 = 'dns1'
 CONF_DNS2 = 'dns2'
 CONF_DOMAIN = 'domain'
+CONF_DRY_ACTION = 'dry_action'
+CONF_DRY_MODE = 'dry_mode'
 CONF_DUMP = 'dump'
 CONF_DURATION = 'duration'
+CONF_EAP = 'eap'
 CONF_ECHO_PIN = 'echo_pin'
 CONF_EFFECT = 'effect'
 CONF_EFFECTS = 'effects'
 CONF_ELSE = 'else'
 CONF_ENABLE_PIN = 'enable_pin'
 CONF_ENABLE_TIME = 'enable_time'
+CONF_ENERGY = 'energy'
 CONF_ENTITY_ID = 'entity_id'
 CONF_ESP8266_RESTORE_FROM_FLASH = 'esp8266_restore_from_flash'
 CONF_ESPHOME = 'esphome'
@@ -149,6 +183,18 @@ CONF_EXPIRE_AFTER = 'expire_after'
 CONF_EXTERNAL_VCC = 'external_vcc'
 CONF_FALLING_EDGE = 'falling_edge'
 CONF_FAMILY = 'family'
+CONF_FAN_MODE = 'fan_mode'
+CONF_FAN_MODE_AUTO_ACTION = 'fan_mode_auto_action'
+CONF_FAN_MODE_DIFFUSE_ACTION = 'fan_mode_diffuse_action'
+CONF_FAN_MODE_FOCUS_ACTION = 'fan_mode_focus_action'
+CONF_FAN_MODE_HIGH_ACTION = 'fan_mode_high_action'
+CONF_FAN_MODE_LOW_ACTION = 'fan_mode_low_action'
+CONF_FAN_MODE_MEDIUM_ACTION = 'fan_mode_medium_action'
+CONF_FAN_MODE_MIDDLE_ACTION = 'fan_mode_middle_action'
+CONF_FAN_MODE_OFF_ACTION = 'fan_mode_off_action'
+CONF_FAN_MODE_ON_ACTION = 'fan_mode_on_action'
+CONF_FAN_ONLY_ACTION = 'fan_only_action'
+CONF_FAN_ONLY_MODE = 'fan_only_mode'
 CONF_FAST_CONNECT = 'fast_connect'
 CONF_FILE = 'file'
 CONF_FILTER = 'filter'
@@ -173,20 +219,25 @@ CONF_GROUP = 'group'
 CONF_HARDWARE_UART = 'hardware_uart'
 CONF_HEARTBEAT = 'heartbeat'
 CONF_HEAT_ACTION = 'heat_action'
+CONF_HEAT_MODE = 'heat_mode'
 CONF_HEATER = 'heater'
 CONF_HIDDEN = 'hidden'
+CONF_HIDE_TIMESTAMP = 'hide_timestamp'
 CONF_HIGH = 'high'
 CONF_HIGH_VOLTAGE_REFERENCE = 'high_voltage_reference'
 CONF_HOUR = 'hour'
 CONF_HOURS = 'hours'
 CONF_HUMIDITY = 'humidity'
+CONF_HYSTERESIS = "hysteresis"
 CONF_I2C = 'i2c'
 CONF_I2C_ID = 'i2c_id'
 CONF_ICON = 'icon'
 CONF_ID = 'id'
+CONF_IDENTITY = 'identity'
 CONF_IDLE = 'idle'
 CONF_IDLE_ACTION = 'idle_action'
 CONF_IDLE_LEVEL = 'idle_level'
+CONF_IDLE_TIME = 'idle_time'
 CONF_IF = 'if'
 CONF_IIR_FILTER = 'iir_filter'
 CONF_ILLUMINANCE = 'illuminance'
@@ -205,10 +256,12 @@ CONF_INVALID_COOLDOWN = 'invalid_cooldown'
 CONF_INVERT = 'invert'
 CONF_INVERTED = 'inverted'
 CONF_IP_ADDRESS = 'ip_address'
+CONF_JS_INCLUDE = 'js_include'
 CONF_JS_URL = 'js_url'
 CONF_JVC = 'jvc'
 CONF_KEEP_ON_TIME = 'keep_on_time'
 CONF_KEEPALIVE = 'keepalive'
+CONF_KEY = 'key'
 CONF_LAMBDA = 'lambda'
 CONF_LEVEL = 'level'
 CONF_LG = 'lg'
@@ -224,8 +277,10 @@ CONF_LOGS = 'logs'
 CONF_LOW = 'low'
 CONF_LOW_VOLTAGE_REFERENCE = 'low_voltage_reference'
 CONF_MAC_ADDRESS = 'mac_address'
+CONF_MAINS_FILTER = 'mains_filter'
 CONF_MAKE_ID = 'make_id'
 CONF_MANUAL_IP = 'manual_ip'
+CONF_MANUFACTURER_ID = 'manufacturer_id'
 CONF_MASK_DISTURBER = 'mask_disturber'
 CONF_MAX_CURRENT = 'max_current'
 CONF_MAX_DURATION = 'max_duration'
@@ -238,7 +293,9 @@ CONF_MAX_TEMPERATURE = 'max_temperature'
 CONF_MAX_VALUE = 'max_value'
 CONF_MAX_VOLTAGE = 'max_voltage'
 CONF_MEASUREMENT_DURATION = 'measurement_duration'
+CONF_MEASUREMENT_SEQUENCE_NUMBER = 'measurement_sequence_number'
 CONF_MEDIUM = 'medium'
+CONF_MEMORY_BLOCKS = 'memory_blocks'
 CONF_METHOD = 'method'
 CONF_MIN_LENGTH = 'min_length'
 CONF_MIN_LEVEL = 'min_level'
@@ -253,6 +310,8 @@ CONF_MODEL = 'model'
 CONF_MOISTURE = 'moisture'
 CONF_MONTHS = 'months'
 CONF_MOSI_PIN = 'mosi_pin'
+CONF_MOTION = 'motion'
+CONF_MOVEMENT_COUNTER = 'movement_counter'
 CONF_MQTT = 'mqtt'
 CONF_MQTT_ID = 'mqtt_id'
 CONF_MULTIPLEXER = 'multiplexer'
@@ -267,8 +326,12 @@ CONF_NUM_CHANNELS = 'num_channels'
 CONF_NUM_CHIPS = 'num_chips'
 CONF_NUM_LEDS = 'num_leds'
 CONF_NUMBER = 'number'
+CONF_OFF_MODE = 'off_mode'
 CONF_OFFSET = 'offset'
 CONF_ON = 'on'
+CONF_ON_BLE_ADVERTISE = 'on_ble_advertise'
+CONF_ON_BLE_MANUFACTURER_DATA_ADVERTISE = 'on_ble_manufacturer_data_advertise'
+CONF_ON_BLE_SERVICE_DATA_ADVERTISE = 'on_ble_service_data_advertise'
 CONF_ON_BOOT = 'on_boot'
 CONF_ON_CLICK = 'on_click'
 CONF_ON_DOUBLE_CLICK = 'on_double_click'
@@ -302,6 +365,7 @@ CONF_OUTPUT = 'output'
 CONF_OUTPUT_ID = 'output_id'
 CONF_OUTPUTS = 'outputs'
 CONF_OVERSAMPLING = 'oversampling'
+CONF_PACKAGES = 'packages'
 CONF_PAGE_ID = 'page_id'
 CONF_PAGES = 'pages'
 CONF_PANASONIC = 'panasonic'
@@ -309,6 +373,7 @@ CONF_PASSWORD = 'password'
 CONF_PAYLOAD = 'payload'
 CONF_PAYLOAD_AVAILABLE = 'payload_available'
 CONF_PAYLOAD_NOT_AVAILABLE = 'payload_not_available'
+CONF_PERIOD = 'period'
 CONF_PHASE_BALANCER = 'phase_balancer'
 CONF_PIN = 'pin'
 CONF_PIN_A = 'pin_a'
@@ -321,8 +386,16 @@ CONF_PLATFORMIO_OPTIONS = 'platformio_options'
 CONF_PM_1_0 = 'pm_1_0'
 CONF_PM_10_0 = 'pm_10_0'
 CONF_PM_2_5 = 'pm_2_5'
+CONF_PM_4_0 = 'pm_4_0'
+CONF_PM_SIZE = 'pm_size'
+CONF_PMC_0_5 = 'pmc_0_5'
+CONF_PMC_1_0 = 'pmc_1_0'
+CONF_PMC_10_0 = 'pmc_10_0'
+CONF_PMC_2_5 = 'pmc_2_5'
+CONF_PMC_4_0 = 'pmc_4_0'
 CONF_PORT = 'port'
 CONF_POSITION = 'position'
+CONF_POSITION_ACTION = 'position_action'
 CONF_POWER = 'power'
 CONF_POWER_FACTOR = 'power_factor'
 CONF_POWER_ON_VALUE = 'power_on_value'
@@ -340,9 +413,13 @@ CONF_RANGE_FROM = 'range_from'
 CONF_RANGE_TO = 'range_to'
 CONF_RATE = 'rate'
 CONF_RAW = 'raw'
+CONF_RC_CODE_1 = 'rc_code_1'
+CONF_RC_CODE_2 = 'rc_code_2'
 CONF_REBOOT_TIMEOUT = 'reboot_timeout'
 CONF_RECEIVE_TIMEOUT = 'receive_timeout'
 CONF_RED = 'red'
+CONF_REFERENCE_RESISTANCE = 'reference_resistance'
+CONF_REFERENCE_TEMPERATURE = 'reference_temperature'
 CONF_REPEAT = 'repeat'
 CONF_REPOSITORY = 'repository'
 CONF_RESET_PIN = 'reset_pin'
@@ -358,9 +435,12 @@ CONF_RGBW = 'rgbw'
 CONF_RISING_EDGE = 'rising_edge'
 CONF_ROTATION = 'rotation'
 CONF_RS_PIN = 'rs_pin'
+CONF_RTD_NOMINAL_RESISTANCE = 'rtd_nominal_resistance'
+CONF_RTD_WIRES = 'rtd_wires'
 CONF_RUN_CYCLES = 'run_cycles'
 CONF_RUN_DURATION = 'run_duration'
 CONF_RW_PIN = 'rw_pin'
+CONF_RX_BUFFER_SIZE = 'rx_buffer_size'
 CONF_RX_ONLY = 'rx_only'
 CONF_RX_PIN = 'rx_pin'
 CONF_SAFE_MODE = 'safe_mode'
@@ -382,6 +462,7 @@ CONF_SENSORS = 'sensors'
 CONF_SEQUENCE = 'sequence'
 CONF_SERVERS = 'servers'
 CONF_SERVICE = 'service'
+CONF_SERVICE_UUID = 'service_uuid'
 CONF_SERVICES = 'services'
 CONF_SETUP_MODE = 'setup_mode'
 CONF_SETUP_PRIORITY = 'setup_priority'
@@ -408,10 +489,18 @@ CONF_STEP_PIN = 'step_pin'
 CONF_STOP = 'stop'
 CONF_STOP_ACTION = 'stop_action'
 CONF_SUBNET = 'subnet'
+CONF_SUBSTITUTIONS = 'substitutions'
 CONF_SUPPORTS_COOL = 'supports_cool'
 CONF_SUPPORTS_HEAT = 'supports_heat'
+CONF_SWING_BOTH_ACTION = 'swing_both_action'
+CONF_SWING_HORIZONTAL_ACTION = 'swing_horizontal_action'
+CONF_SWING_MODE = 'swing_mode'
+CONF_SWING_OFF_ACTION = 'swing_off_action'
+CONF_SWING_VERTICAL_ACTION = 'swing_vertical_action'
+CONF_SWITCH_DATAPOINT = "switch_datapoint"
 CONF_SWITCHES = 'switches'
 CONF_SYNC = 'sync'
+CONF_TABLET = 'tablet'
 CONF_TAG = 'tag'
 CONF_TARGET = 'target'
 CONF_TARGET_TEMPERATURE = 'target_temperature'
@@ -443,6 +532,7 @@ CONF_TURN_OFF_ACTION = 'turn_off_action'
 CONF_TURN_ON_ACTION = 'turn_on_action'
 CONF_TX_BUFFER_SIZE = 'tx_buffer_size'
 CONF_TX_PIN = 'tx_pin'
+CONF_TX_POWER = 'tx_power'
 CONF_TYPE = 'type'
 CONF_TYPE_ID = 'type_id'
 CONF_UART_ID = 'uart_id'
@@ -451,6 +541,7 @@ CONF_UNIQUE = 'unique'
 CONF_UNIT_OF_MEASUREMENT = 'unit_of_measurement'
 CONF_UPDATE_INTERVAL = 'update_interval'
 CONF_UPDATE_ON_BOOT = 'update_on_boot'
+CONF_URL = 'url'
 CONF_USE_ADDRESS = 'use_address'
 CONF_USERNAME = 'username'
 CONF_UUID = 'uuid'
@@ -477,35 +568,45 @@ CONF_WIND_SPEED = 'wind_speed'
 CONF_WINDOW_SIZE = 'window_size'
 CONF_ZERO = 'zero'
 
+ICON_ACCELERATION = 'mdi:axis-arrow'
+ICON_ACCELERATION_X = 'mdi:axis-x-arrow'
+ICON_ACCELERATION_Y = 'mdi:axis-y-arrow'
+ICON_ACCELERATION_Z = 'mdi:axis-z-arrow'
 ICON_ARROW_EXPAND_VERTICAL = 'mdi:arrow-expand-vertical'
 ICON_BATTERY = 'mdi:battery'
 ICON_BRIEFCASE_DOWNLOAD = 'mdi:briefcase-download'
 ICON_BRIGHTNESS_5 = 'mdi:brightness-5'
+ICON_BUG = 'mdi:bug'
 ICON_CHECK_CIRCLE_OUTLINE = 'mdi:check-circle-outline'
 ICON_CHEMICAL_WEAPON = 'mdi:chemical-weapon'
+ICON_COUNTER = 'mdi:counter'
 ICON_CURRENT_AC = 'mdi:current-ac'
 ICON_EMPTY = ''
 ICON_FLASH = 'mdi:flash'
+ICON_FLASK_OUTLINE = 'mdi:flask-outline'
 ICON_FLOWER = 'mdi:flower'
 ICON_GAS_CYLINDER = 'mdi:gas-cylinder'
 ICON_GAUGE = 'mdi:gauge'
 ICON_LIGHTBULB = 'mdi:lightbulb'
 ICON_MAGNET = 'mdi:magnet'
+ICON_MOLECULE_CO2 = 'mdi:molecule-co2'
+ICON_MOTION_SENSOR = 'mdi:motion-sensor'
 ICON_NEW_BOX = 'mdi:new-box'
 ICON_PERCENT = 'mdi:percent'
-ICON_PERIODIC_TABLE_CO2 = 'mdi:periodic-table-co2'
 ICON_POWER = 'mdi:power'
 ICON_PULSE = 'mdi:pulse'
 ICON_RADIATOR = 'mdi:radiator'
 ICON_RESTART = 'mdi:restart'
 ICON_ROTATE_RIGHT = 'mdi:rotate-right'
+ICON_RULER = 'mdi:ruler'
 ICON_SCALE = 'mdi:scale'
 ICON_SCREEN_ROTATION = 'mdi:screen-rotation'
 ICON_SIGN_DIRECTION = 'mdi:sign-direction'
-ICON_SIGNAL = 'mdi: signal-distance-variant'
+ICON_SIGNAL = 'mdi:signal-distance-variant'
 ICON_SIGNAL_DISTANCE_VARIANT = 'mdi:signal'
 ICON_THERMOMETER = 'mdi:thermometer'
-ICON_TIMER = 'mdi:timer'
+ICON_TIMELAPSE = 'mdi:timelapse'
+ICON_TIMER = 'mdi:timer-outline'
 ICON_WATER_PERCENT = 'mdi:water-percent'
 ICON_WEATHER_SUNSET = 'mdi:weather-sunset'
 ICON_WEATHER_SUNSET_DOWN = 'mdi:weather-sunset-down'
@@ -514,11 +615,14 @@ ICON_WEATHER_WINDY = 'mdi:weather-windy'
 ICON_WIFI = 'mdi:wifi'
 
 UNIT_AMPERE = 'A'
-UNIT_CELSIUS = u'°C'
+UNIT_CELSIUS = '°C'
+UNIT_COUNTS_PER_CUBIC_METER = '#/m³'
 UNIT_DECIBEL = 'dB'
-UNIT_DEGREE_PER_SECOND = u'°/s'
-UNIT_DEGREES = u'°'
+UNIT_DECIBEL_MILLIWATT = 'dBm'
+UNIT_DEGREE_PER_SECOND = '°/s'
+UNIT_DEGREES = '°'
 UNIT_EMPTY = ''
+UNIT_G = 'G'
 UNIT_HECTOPASCAL = 'hPa'
 UNIT_HERTZ = 'hz'
 UNIT_KELVIN = 'K'
@@ -526,11 +630,14 @@ UNIT_KILOMETER = 'km'
 UNIT_KILOMETER_PER_HOUR = 'km/h'
 UNIT_LUX = 'lx'
 UNIT_METER = 'm'
-UNIT_METER_PER_SECOND_SQUARED = u'm/s²'
-UNIT_MICROGRAMS_PER_CUBIC_METER = u'µg/m³'
-UNIT_MICROSIEMENS_PER_CENTIMETER = u'µS/cm'
-UNIT_MICROTESLA = u'µT'
-UNIT_OHM = u'Ω'
+UNIT_METER_PER_SECOND_SQUARED = 'm/s²'
+UNIT_MICROGRAMS_PER_CUBIC_METER = 'µg/m³'
+UNIT_MICROMETER = 'µm'
+UNIT_MICROSIEMENS_PER_CENTIMETER = 'µS/cm'
+UNIT_MICROTESLA = 'µT'
+UNIT_MILLIGRAMS_PER_CUBIC_METER = 'mg/m³'
+UNIT_MINUTE = 'min'
+UNIT_OHM = 'Ω'
 UNIT_PARTS_PER_BILLION = 'ppb'
 UNIT_PARTS_PER_MILLION = 'ppm'
 UNIT_PERCENT = '%'
@@ -541,6 +648,7 @@ UNIT_VOLT = 'V'
 UNIT_VOLT_AMPS = 'VA'
 UNIT_VOLT_AMPS_REACTIVE = 'VAR'
 UNIT_WATT = 'W'
+UNIT_WATT_HOURS = 'Wh'
 
 DEVICE_CLASS_CONNECTIVITY = 'connectivity'
 DEVICE_CLASS_MOVING = 'moving'
